@@ -41,10 +41,10 @@ def javascript_datatypes_filter(value: util.JSONType) -> str:
     return "".join(JavascriptEncoder().iterencode(value))
 
 
-def class_name_factory(platform: str, namespace: str) -> Callable[[str], str]:
+def class_name_factory(platform: str) -> Callable[[str], str]:
     """
     Returns a function that receives an obj_type and
-    returns the correct class name for that time in the current platform.
+    returns the correct class name for that type in the current platform.
     """
 
     def class_name(obj_type: str) -> str:
@@ -56,13 +56,23 @@ def class_name_factory(platform: str, namespace: str) -> Callable[[str], str]:
             class_name = util.Camelize(obj_type) + "MetricType"
 
         if platform == "qt":
-            return namespace + ".Glean.default._private." + class_name
+            return "Glean.Glean._private." + class_name
 
         return class_name
 
     return class_name
 
 
+def extra_type_name(extra_type: str) -> str:
+    """
+    Returns the equivalent TypeScript type to an extra type.
+    """
+    if extra_type == "quantity":
+        return "number"
+
+    return extra_type
+
+
 def import_path(obj_type: str) -> str:
     """
     Returns the import path of the given object inside the @mozilla/glean package.
@@ -101,24 +111,33 @@ def output(
         `parser.parse_objects`.
     :param output_dir: Path to an output directory to write to.
     :param options: options dictionary, with the following optional keys:
-
-        - `namespace`: The identifier of the global variable Glean was assigned to.
-                       This will only have and effect for Qt and static web sites.
-                       Default is `Glean`.
         - `platform`: Which platform are we building for. Options are `webext` and `qt`.
                       Default is `webext`.
+        - `version`: The version of the Glean.js Qt library being used.
+                     This option is mandatory when targeting Qt. Note that the version
+                     string must only contain the major and minor version i.e. 0.14.
+
     """
 
     if options is None:
         options = {}
 
-    namespace = options.get("namespace", "Glean")
     platform = options.get("platform", "webext")
+    if platform not in ["qt", "webext"]:
+        raise ValueError(
+            f"Unknown platform: {platform}. Accepted platforms are qt and webext."
+        )
+    version = options.get("version")
+    if platform == "qt" and version is None:
+        raise ValueError(
+            "'version' option is required when building for the 'qt' platform."
+        )
 
     template = util.get_jinja2_template(
         "javascript.jinja2",
         filters=(
-            ("class_name", class_name_factory(platform, namespace)),
+            ("class_name", class_name_factory(platform)),
+            ("extra_type_name", extra_type_name),
             ("import_path", import_path),
             ("js", javascript_datatypes_filter),
             ("args", args),
@@ -151,8 +170,8 @@ def output(
                     category_name=category_key,
                     objs=category_val,
                     extra_args=util.extra_args,
-                    namespace=namespace,
                     platform=platform,
+                    version=version,
                     has_labeled_metrics=has_labeled_metrics,
                     types=types,
                     lang=lang,
@@ -161,6 +180,16 @@ def output(
             # Jinja2 squashes the final newline, so we explicitly add it
             fd.write("\n")
 
+    if platform == "qt":
+        # Explicitly create a qmldir file when building for Qt
+        template = util.get_jinja2_template("qmldir.jinja2")
+        filepath = output_dir / "qmldir"
+
+        with filepath.open("w", encoding="utf-8") as fd:
+            fd.write(template.render(categories=objs.keys(), version=version))
+            # Jinja2 squashes the final newline, so we explicitly add it
+            fd.write("\n")
+
 
 def output_javascript(
     objs: metrics.ObjectTree, output_dir: Path, options: Optional[Dict[str, Any]] = None
